==========
Changelog
==========

This project adheres to `Semantic Versioning <https://semver.org/>`_.

2.0.1 (2021-04-08)
------------------

**Added**

**Fixed**

**Dependencies**

**Deprecated**


2.0.0 (2021-04-08)
------------------

**Added**

* Added model (v2) trained on recount2 TCGA/GTEx liver(cancer) data obtained from mlf-core/lcep
* Replaced test data

**Fixed**

**Dependencies**

**Deprecated**


1.2.0 (2020-08-28)
------------------

**Added**

* Added flag --cuda and --no-cuda to enable and disable GPU prediction

**Fixed**

**Dependencies**

**Deprecated**


1.1.0 (2020-08-28)
------------------

**Added**

**Fixed**

* help command message

**Dependencies**

**Deprecated**


1.0.0 (2020-08-28)
------------------

**Added**

* Parsing of an appropriate data input file
* Loading an already trained model and performing predictions
* Writing the predictions to an output file

**Fixed**

**Dependencies**

**Deprecated**


0.1.0 (2020-08-28)
------------------

**Added**

* Created the project using cookietemple

**Fixed**

**Dependencies**

**Deprecated**
